/*
 * hpiudp_cache.c
 *
 * Control caching module.
 *
 * (c) AudioScience, 2012
 *
 */
#ifndef _HPIUDP_CACHE_H_
#define _HPIUDP_CACHE_H_

#ifdef HPIUDP_USE_CACHE

struct hpi_adapter;

struct hpiudp_cache_update_time {
	uint32_t all_info;
	uint32_t value;
	uint32_t limits;
};

struct hpiudp_cache_context {
	//unsigned int nControls;
	unsigned int timeStamp_ms;
	struct hpi_control_defn *controlDef;
	//size_t cache_size;
	uint8_t *controlCacheData;
	struct hpi_control_cache *controlCache;
	/** pointer to timestamp information. */
	struct hpiudp_cache_update_time *pTimeStamp;
};

typedef int (*ptr_fn_messsage)(struct hpi_adapter *pA,
	struct hpi_message *phm,
	struct hpi_response *phr,
	const unsigned int nThisTimeout_ms);

int hpudp_cache_init(
	struct hpi_adapter *pA,
	uint16_t adapter_index,
	struct hpiudp_cache_context **cache,
	ptr_fn_messsage msg_fn,
	struct hpi_response *phr);

void hpiudp_cache_free(
	struct hpiudp_cache_context **cache);

int hpiudp_cache_message(
	struct hpi_adapter *pA,
	uint16_t adapter_index,
	uint32_t *mixer_is_open,
	struct hpiudp_cache_context **cache,
	ptr_fn_messsage msg_fn,
	struct hpi_message *phm,
	struct hpi_response *phr,
	int *nHandled,
	int *nCachingError);

int hpiudp_cache_check_for_control(struct hpi_adapter *pA,
	uint16_t adapter_index,
	struct hpiudp_cache_context *cache,
	struct hpi_message *phm,
	struct hpi_response *phr,
	int *nHandled,
	int *nCachingError);

int hpiudp_cache_update(
	struct hpi_adapter *pA,
	uint16_t adapter_index,
	struct hpiudp_cache_context *cache,
	ptr_fn_messsage msg_fn,
	struct hpi_response *phr,
	const unsigned int nTimeOut_ms);

int hpiudp_cache_update_now(struct hpi_adapter *pA,
		uint16_t adapter_index,
		struct hpiudp_cache_context *cache_context,
		ptr_fn_messsage msg_fn,
		struct hpi_response *phr,
		const unsigned int nTimeOut_ms,
		unsigned int timestamp);
#endif
#endif
